==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ca.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendari",
    "Todos" : "Tasques",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
    "You created calendar {calendar}" : "Heu creat el calendari {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha suprimit el calendari {calendar}",
    "You deleted calendar {calendar}" : "Heu suprimit el calendari {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha actualitzat el calendari {calendar}",
    "You updated calendar {calendar}" : "Heu actualitzat el calendari {calendar}",
    "You shared calendar {calendar} as public link" : "Heu compartit el calendari {calendar} amb un enllaç públic",
    "You removed public link for calendar {calendar}" : "Heu eliminat l'enllaç públic del calendari {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartit el calendari {calendar} amb vós",
    "You shared calendar {calendar} with {user}" : "Heu compartit el calendari {calendar} amb {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha deixat de compartir el calendari {calendar} amb vós",
    "You unshared calendar {calendar} from {user}" : "Heu deixat de compartir el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} no ha compartit el calendari {calendar}  amb {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} no comparteixen el calendari {calendar} de si mateixos",
    "You shared calendar {calendar} with group {group}" : "Heu compartit el calendari {calendar} amb el grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha compartit el calendari {calendar} amb el grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Heu desactivat el calendari {calendar} del grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} calendari no publicat {calendar} del grup {grup}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creat l'esdeveniment {event} al calendari {calendar}",
    "You created event {event} in calendar {calendar}" : "Heu creat l'esdeveniment {event} al calendari {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha suprimit l'esdeveniment {esdeveniment} del calendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Heu suprimit l'esdeveniment {event} del calendari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} esdeveniment actualitzat {esdeveniment} al calendari {calendar}",
    "You updated event {event} in calendar {calendar}" : "Heu actualitzat l'esdeveniment {event} al calendari {calendar}",
    "Busy" : "Ocupat",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ha creat la tasca {todo} a {calendar}",
    "You created todo {todo} in list {calendar}" : "Heu creat la tasca {todo} a {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} ha suprimit la tasca {todo} de la llista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Heu suprimit la tasca {todo} de la llista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ha actualitzat la tasca {todo} a {calendar}",
    "You updated todo {todo} in list {calendar}" : "Heu actualitzat la tasca {todo} a {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ha resolt la tasca {todo} a {calendar}",
    "You solved todo {todo} in list {calendar}" : "Heu resolt la tasca {todo} a {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha tornat a obrir la tasca {todo} a {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Heu tornat a obrir la tasca {todo} a {calendar}",
    "A <strong>calendar</strong> was modified" : "El <strong>calendari</strong> has estat modificat",
    "A calendar <strong>event</strong> was modified" : "S'ha modificat un <strong> esdeveniment </strong> del calendari",
    "A calendar <strong>todo</strong> was modified" : "S'ha modificat una <strong>tasca</strong> d'un calendari",
    "Death of %s" : "Mort de %s",
    "Contact birthdays" : "Aniversaris dels contactes",
    "Calendar:" : "Calendari:",
    "Date:" : "Data:",
    "Where:" : "On:",
    "Description:" : "Descripció:",
    "Untitled event" : "Esdeveniment sense títol",
    "_%n year_::_%n years_" : ["%n any","%n anys"],
    "_%n month_::_%n months_" : ["%n mes","%n mesos"],
    "_%n day_::_%n days_" : ["%n dia","%n dies"],
    "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuts"],
    "%s (in %s)" : "%s (d'aquí a %s)",
    "%s (%s ago)" : "%s (fa %s)",
    "Calendar: %s" : "Calendari: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descripció: %s",
    "Where: %s" : "On: %s",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Invitation canceled" : "Invitació cancel·lada",
    "Hello %s," : "Hola, %s,",
    "The meeting »%1$s« with %2$s was canceled." : "La reunió »%1$s« amb %2$s ha estat cancel·lada.",
    "Invitation updated" : "Invitació actualitzada",
    "The meeting »%1$s« with %2$s was updated." : "La reunió »%1$s« amb %2$s ha estat actualitzada.",
    "%1$s invited you to »%2$s«" : "%1$s us ha convidat a »%2$s«",
    "When:" : "Quan:",
    "Link:" : "Enllaç:",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "More options …" : "Més opcions ...",
    "More options at %s" : "Més opcions a %s",
    "Contacts" : "Contactes",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "El vostre %scal configurar-se per utilitzar HTTPS per poder fer servir CalDAV i CardDAV amb iOS/macOS. cal ",
    "Configures a CalDAV account" : "Configura un compte CalDAV",
    "Configures a CardDAV account" : "Configura un compte CardDAV",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Punt final de WebDAV",
    "There was an error updating your attendance status." : "S'ha produït un error en actualitzar l'estat de la vostra assistència.",
    "Please contact the organizer directly." : "Si us plau contacteu amb l'organitzador directament.",
    "Are you accepting the invitation?" : "Accepteu la invitació?",
    "Tentative" : "Provisional",
    "Save" : "Desa",
    "Your attendance was updated successfully." : "La vostra assistència ha estat actualitzada correctament.",
    "Calendar server" : "Servidor de calendari",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instal·leu també {calendarappstoreopen}l’aplicació de Calendari{linkclose} o {calendardocopen}connecteu el vostre escriptori i el mòbil per sincronitzar ↗{linkclose}.",
    "Send invitations to attendees" : "Envia invitacions als assistents",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Si us plau, assegureu-vos de configurar correctament {emailopen}el servidor de correu electrònic{linkclose}.",
    "Automatically generate a birthday calendar" : "Genera automàticament un calendari d’aniversari",
    "Birthday calendars will be generated by a background job." : "Els calendaris d'aniversari es generaran per un procés en segon pla..",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per tant, no estaran disponibles immediatament després d'habilitar-los, però apareixeran d'aquí una estona.",
    "Send notifications for events" : "Envia notificacions per als esdeveniments",
    "Notifications are sent via background jobs, so these must occur often enough." : "Les notificacions s'envien per tasques funcionant en segon pla, així que això ha de succeir bastant sovint.",
    "Enable notifications for events via push" : "Habiliteu les notificacions per a esdeveniments mitjançant l'empenta.",
    "Technical details" : "Detalls tècnics",
    "Remote Address: %s" : "Adreça remota: %s",
    "Request ID: %s" : "Sol·licitud ID: %s ",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Les notificacions s'enviaran a través de tasques en segon terme; per tant, cal que succeeixin prou sovint."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/ca.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendari",
    "Todos" : "Tasques",
    "Personal" : "Personal",
    "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
    "You created calendar {calendar}" : "Heu creat el calendari {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha suprimit el calendari {calendar}",
    "You deleted calendar {calendar}" : "Heu suprimit el calendari {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha actualitzat el calendari {calendar}",
    "You updated calendar {calendar}" : "Heu actualitzat el calendari {calendar}",
    "You shared calendar {calendar} as public link" : "Heu compartit el calendari {calendar} amb un enllaç públic",
    "You removed public link for calendar {calendar}" : "Heu eliminat l'enllaç públic del calendari {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha compartit el calendari {calendar} amb vós",
    "You shared calendar {calendar} with {user}" : "Heu compartit el calendari {calendar} amb {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha compartit el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha deixat de compartir el calendari {calendar} amb vós",
    "You unshared calendar {calendar} from {user}" : "Heu deixat de compartir el calendari {calendar} amb {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} no ha compartit el calendari {calendar}  amb {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} no comparteixen el calendari {calendar} de si mateixos",
    "You shared calendar {calendar} with group {group}" : "Heu compartit el calendari {calendar} amb el grup {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha compartit el calendari {calendar} amb el grup {group}",
    "You unshared calendar {calendar} from group {group}" : "Heu desactivat el calendari {calendar} del grup {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} calendari no publicat {calendar} del grup {grup}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creat l'esdeveniment {event} al calendari {calendar}",
    "You created event {event} in calendar {calendar}" : "Heu creat l'esdeveniment {event} al calendari {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha suprimit l'esdeveniment {esdeveniment} del calendari {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Heu suprimit l'esdeveniment {event} del calendari {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} esdeveniment actualitzat {esdeveniment} al calendari {calendar}",
    "You updated event {event} in calendar {calendar}" : "Heu actualitzat l'esdeveniment {event} al calendari {calendar}",
    "Busy" : "Ocupat",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ha creat la tasca {todo} a {calendar}",
    "You created todo {todo} in list {calendar}" : "Heu creat la tasca {todo} a {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} ha suprimit la tasca {todo} de la llista {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Heu suprimit la tasca {todo} de la llista {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ha actualitzat la tasca {todo} a {calendar}",
    "You updated todo {todo} in list {calendar}" : "Heu actualitzat la tasca {todo} a {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ha resolt la tasca {todo} a {calendar}",
    "You solved todo {todo} in list {calendar}" : "Heu resolt la tasca {todo} a {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha tornat a obrir la tasca {todo} a {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Heu tornat a obrir la tasca {todo} a {calendar}",
    "Calendar and tasks" : "Calendari i tasques",
    "A <strong>calendar</strong> was modified" : "El <strong>calendari</strong> has estat modificat",
    "A calendar <strong>event</strong> was modified" : "S'ha modificat un <strong> esdeveniment </strong> del calendari",
    "A calendar <strong>todo</strong> was modified" : "S'ha modificat una <strong>tasca</strong> d'un calendari",
    "Death of %s" : "Mort de %s",
    "Contact birthdays" : "Aniversaris dels contactes",
    "Calendar:" : "Calendari:",
    "Date:" : "Data:",
    "Where:" : "On:",
    "Description:" : "Descripció:",
    "Untitled event" : "Esdeveniment sense títol",
    "_%n year_::_%n years_" : ["%n any","%n anys"],
    "_%n month_::_%n months_" : ["%n mes","%n mesos"],
    "_%n day_::_%n days_" : ["%n dia","%n dies"],
    "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
    "_%n minute_::_%n minutes_" : ["%n minut","%n minuts"],
    "%s (in %s)" : "%s (d'aquí a %s)",
    "%s (%s ago)" : "%s (fa %s)",
    "Calendar: %s" : "Calendari: %s",
    "Date: %s" : "Data: %s",
    "Description: %s" : "Descripció: %s",
    "Where: %s" : "On: %s",
    "%1$s via %2$s" : "%1$s mitjançant %2$s",
    "Invitation canceled" : "Invitació cancel·lada",
    "Invitation updated" : "Invitació actualitzada",
    "Invitation" : "Invitació",
    "Title:" : "Títol:",
    "Time:" : "Hora:",
    "Location:" : "Ubicació:",
    "Link:" : "Enllaç:",
    "Organizer:" : "Organitzador:",
    "Attendees:" : "Assistents:",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "More options …" : "Més opcions …",
    "More options at %s" : "Més opcions a %s",
    "Contacts" : "Contactes",
    "System in maintenance mode." : "Sistema en mode de manteniment.",
    "Upgrade needed" : "Fa falta l'actualització",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "El vostre %s cal configurar-se per utilitzar HTTPS per poder fer servir CalDAV i CardDAV amb iOS/macOS.",
    "Configures a CalDAV account" : "Configura un compte CalDAV",
    "Configures a CardDAV account" : "Configura un compte CardDAV",
    "Events" : "Esdeveniments",
    "Tasks" : "Tasques",
    "Untitled task" : "Tasca sense títol",
    "Completed on %s" : "Completat a %s",
    "Due on %s by %s" : "Venciment a %s per %s",
    "Due on %s" : "Venç en %s",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "Punt final de WebDAV",
    "There was an error updating your attendance status." : "S'ha produït un error en actualitzar l'estat de la vostra assistència.",
    "Please contact the organizer directly." : "Si us plau contacteu amb l'organitzador directament.",
    "Are you accepting the invitation?" : "Accepteu la invitació?",
    "Tentative" : "Provisional",
    "Save" : "Desa",
    "Your attendance was updated successfully." : "La vostra assistència ha estat actualitzada correctament.",
    "Calendar server" : "Servidor de calendari",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Instal·leu també {calendarappstoreopen}l’aplicació de Calendari{linkclose} o {calendardocopen}connecteu el vostre escriptori i el mòbil per sincronitzar ↗{linkclose}.",
    "Send invitations to attendees" : "Envia invitacions als assistents",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Si us plau, assegureu-vos de configurar correctament {emailopen}el servidor de correu electrònic{linkclose}.",
    "Automatically generate a birthday calendar" : "Genera automàticament un calendari d’aniversari",
    "Birthday calendars will be generated by a background job." : "Els calendaris d'aniversari es generaran per un procés en segon pla..",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Per tant, no estaran disponibles immediatament després d'habilitar-los, però apareixeran d'aquí una estona.",
    "Send notifications for events" : "Envia notificacions per als esdeveniments",
    "Notifications are sent via background jobs, so these must occur often enough." : "Les notificacions s'envien per tasques funcionant en segon pla, així que això ha de succeir bastant sovint.",
    "Enable notifications for events via push" : "Habiliteu les notificacions per a esdeveniments mitjançant l’empenyiment",
    "Hello %s," : "Hola, %s,",
    "The meeting »%1$s« with %2$s was canceled." : "La reunió »%1$s« amb %2$s ha estat cancel·lada.",
    "The meeting »%1$s« with %2$s was updated." : "La reunió »%1$s« amb %2$s ha estat actualitzada.",
    "%1$s invited you to »%2$s«" : "%1$s us ha convidat a »%2$s«",
    "When:" : "Quan:"
},
"nplurals=2; plural=(n != 1);");
